<template>
    <div class="full-page bg">
        <div class="search-container">
            <div class="search_left">
                <div class="item" v-for="(item, index) in tabList" :class="{ active: isActive === index }"
                    @click="checkTab(index)">
                    <div :style="{ background: item.color }" v-if="index > 0">
                    </div>
                    {{ item.text }}
                </div>
            </div>
        </div>
        <el-row :gutter="10" class="main-table-container flex">
            <el-col :span="24" class="table-container" ref="contentPanel" style="padding: 20px">
                <div style="margin-bottom: 10px" ref="btnPanel">
                </div>
                <div :style="{ width: '100%', height: `${tableMaxHeight}` + 'px' }">
                    <el-table stripe size="mini" v-loading="tableLoading" ref="multipleSelection" :data="tableData"
                        :max-height="tableMaxHeight" :style="{
                            width: '100%',
                            height: `${tableMaxHeight}` + 'px'
                        }" @selection-change="handleSelectionChange">
                        <el-table-column type="index" width="55" label="序号" align="center">
                        </el-table-column>
                        <el-table-column prop="name" show-overflow-tooltip min-width="280" align="center" label="名称">
                        </el-table-column>
                        <el-table-column prop="state" show-overflow-tooltip width="290" align="center" label="状态">
                            <!-- <template v-slot="{ row }">
                                {{ getDictName('ggbb_lyqd', row.demandSourceChannel) }}
                            </template> -->
                        </el-table-column>
                        <el-table-column prop="time" show-overflow-tooltip min-width="280" align="center" label="时间">
                        </el-table-column>
                    </el-table>
                </div>
                <pagination ref="paginationPanel" style="margin-top: 10px" :pageResult="params.pageBean"
                    @size-change="handleSizeChange" @current-change="handleCurrentChange" />
            </el-col>
        </el-row>
    </div>
</template>
  
<script>
import pagination from '@/components/pagination'
import { TableMixin } from '@/mixins/tableMixin'
import req from '@/request.js'
import utils from '@/utils.js'
const portal = window.context.portal
export default {
    name: 'DemandEntry',
    components: {
        pagination,
    },
    mixins: [TableMixin],
    data() {
        return {
            tableMaxHeight: 400,
            loading: false,
            tableLoading: false,
            tableData: [
                {
                    name: '张三',
                    state: '已认证',
                    time: '2023-10-30'
                },
                {
                    name: '李四',
                    state: '未认证',
                    time: '2023-10-29'
                }
            ],
            multipleSelection: [],
            params: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    total: 0
                }
            },
            isActive: 0,
            tabList: [{
                text: '全部',
                color: ''
            },
            {
                text: '已认证',
                color: '#44b4ad'
            },
            {
                text: '未认证',
                color: '#999999'
            }
            ],




            searchForm: {}, // 顶部搜索对象
            currentDataDel: [],
            options: [{
                name: '已认证', value: '1'
            }, {
                name: '未认证', value: '2'

            }],
        }
    },

    created() {
    },
    methods: {
        //字典回显
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        //获取数据
        loadData() {
            this.tableLoading = true
        },
        //添加
        handleAdd() {
            this.$refs.UnitRegistrationDialog.add()
        },
        // 删除
        handleDelete() {
            this.$confirm('确定删除选中数据吗？', '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'warning'
            }).then(() => {

            })
        },
        //修改
        handleDbClick(row) {
            this.$refs.UnitRegistrationDialog.edit(row)
        },
        // 顶部搜索
        handleSearch() {

        },
        checkTab(val){
            this.isActive=val
        },
        //表格选中
        handleSelectionChange(currentData) {
        },
        //分页页数
        handleCurrentChange(page) {
            this.params.pageBean = { ...this.params.pageBean, page }
            this.loadData(this.params)
        },
        //分页大小
        handleSizeChange(pageSize) {
            this.params.pageBean = { ...this.params.pageBean, pageSize }
            this.loadData(this.params)
        }
    }
}
</script>
  
<style lang="scss" scoped>
.common-tree-container {
    height: calc(100% - 70px);
    margin-top: 0.52083vw;
    padding: 1.04167vw 1.04167vw;
    background-color: #fff;
    position: relative;
    box-sizing: border-box;
    overflow-y: auto;
    border-radius: 20px;
    box-shadow: 0px 0px 0.625vw 0 rgba(92, 102, 83, 0.2);
}

.container-head {
    display: flex;
    align-items: center;

    i {
        font-size: 16px;
        margin-left: 5px;
        font-weight: 600;
        cursor: pointer;
    }
}

.move-tree /deep/ .el-tree {
    height: 90%;
    overflow-y: auto;
    border: none;
}

.cloumn-btn {
    border: 1px solid #2761ff;
    padding: 3px 10px;
    border-radius: 5px;

    &:nth-child(1) {
        margin-right: 5px;
    }

    &:nth-child(2) {
        margin-right: 5px;
    }

    &:nth-child(1):hover {
        background-color: #2761ff;
        color: #fff;
    }

    &:nth-child(2):hover {
        background-color: #2761ff;
        color: #fff;
    }

    // &:nth-child(2):hover {
    //   background-color: #f56c6c;
    //   color: #fff;
    //   border-color: #f56c6c;
    // }
    /deep/ i,
    span {
        font-size: 16px;
    }
}

/deep/ .el-tree-node__content {
    padding: 5px 0;
}

.search_left {
    display: flex;
    align-items: center;
    flex-wrap: wrap;

    .item {
        height: 50px;
        margin-right: 30px;
        display: flex;
        margin-top: 4px;
        align-items: center;
        border-bottom: #ffffff 4px solid;
        cursor: pointer;

        div {
            width: 14px;
            height: 14px;
            margin-right: 5px;
            border-radius: 50%;
        }
    }

    .active {
        border-bottom: #0147eb 4px solid;
    }
}
</style>
  